@@ -1,7 +1,8 @@
 import os
-import imp
 import ast
+import types
 import logging
+import multiprocessing
 
 
 logger = logging.getLogger(__name__)
@@ -128,23 +129,51 @@ class Config(object):
     """Manager HTTP port that the Flask application will run on."""
 
     def from_object(self, obj):
-        """Loads values from an object."""
+        """Load values from an object."""
         for key in dir(obj):
             if key.isupper():
                 value = getattr(obj, key)
                 setattr(self, key, value)
-        logger.info("Config is loaded from %r", obj)
+        logger.info("Config is loaded from object: %r", obj)
+
+    def from_dict(self, d):
+        """Load values from a dict."""
+        for key, value in d.iteritems():
+            if key.isupper():
+                setattr(self, key, value)
+        logger.info("Config is loaded from dict: %r", d)
 
     def from_pyfile(self, filename):
-        """Loads values from a Python file."""
-        d = imp.new_module('kuyruk_config')
-        d.__file__ = filename
-        try:
-            execfile(filename, d.__dict__)
-        except IOError as e:
-            e.strerror = 'Unable to load configuration file (%s)' % e.strerror
-            raise
-        self.from_object(d)
+        """Load values from a Python file."""
+        # Read the config file from a seperate process because it may contain
+        # import statements doing import from user code. No user code should
+        # be imported to master because they have to be imported in workers
+        # after the master has forked. Otherwise newly created workers
+        # cannot load new code after the master has started.
+        def readfile(conn):
+            logger.debug("Reading config file from seperate process...")
+            try:
+                globals_, locals_ = {}, {}
+                execfile(filename, globals_, locals_)
+                values = {}
+                for key, value in locals_.iteritems():
+                    if (key.isupper() and
+                            not isinstance(value, types.ModuleType)):
+                        values[key] = value
+                conn.send(values)
+                logger.debug("Config read successfully")
+            except:
+                logger.debug("Cannot read config")
+                conn.send(None)
+        parent_conn, child_conn = multiprocessing.Pipe()
+        process = multiprocessing.Process(target=readfile,
+                                          args=(child_conn, ))
+        process.start()
+        values = parent_conn.recv()
+        process.join()
+        assert values is not None, "Cannot load config file: %s" % filename
+        self.from_dict(values)
+        logger.info("Config is loaded from file: %s", filename)
 
     def from_env_vars(self):
         """Load values from environment variables."""
